﻿using DatabaseCore.Models.Department;
using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.AcademicProgress
{
    /// <summary>
    /// Класс, описывающий запись успеваемости студента
    /// </summary>
    [DataContract]
    [EntityDescription("StudentAcademicProgress", "Запись успеваемости студента")]
    [EntityDependency("Discipline", "DisciplineId", "Дисциплина, которая указана в записи успеваемости")]
    [EntityDependency("Student", "StudentId", "Студент, для которого запрашивается успеваемость")]
    public class StudentAcademicProgress : BaseEntity, IEntitySecurityExtenstion<StudentAcademicProgress>
    {
        [DataMember]
        [Required(ErrorMessage = "required")]
        [MapConfiguration("StudentId")]
        public Guid StudentId { get; set; }

        [DataMember]
        [Required(ErrorMessage = "required")]
        [MapConfiguration("DisciplineId")]
        public Guid DisciplineId { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("Semester")]
        public int Semester { get; set; }

        [DataMember]
        [Required(ErrorMessage = "required")]
        [MapConfiguration("Score")]
        public int Score { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("AffixingDate")]
        public DateTime AffixingDate { get; set; }

        [DataMember]
        [MapConfiguration("IsIncreaseScore")]
        public bool IsIncreaseScore { get; set; }

        [DataMember]
        [MapConfiguration("IsResit")]
        public bool IsResit { get; set; }

        //-------------------------------------------------------------------------
        public virtual Student Student { get; set; }

        public virtual Discipline Discipline { get; set; }

        //-------------------------------------------------------------------------

        public StudentAcademicProgress SecurityCheck(StudentAcademicProgress entity, bool allowFullData) => entity;

        public override string ToString() => $"{Student}-{Discipline}";

    }
}
