﻿using DepartmentBusinessLogic.Enums;
using ModuleTools.Attributes;
using ModuleTools.Enums;
using ModuleTools.ViewModels;
using System;

namespace DepartmentBusinessLogic.ViewModels
{
	/// <summary>
	/// Список учебных групп
	/// </summary>
	public class StudentGroupListViewModel : ListViewModel<StudentGroupViewModel> { }

	/// <summary>
	/// Элемент учебная группа
	/// </summary>
	[ViewModelControlElementClass(HaveDependenceEntities = true, Width = 800, Height = 500)]
	[ViewModelControlElementDependenceEntity(Title = "Студенты", Order = 1, ParentPropertyName = "StudentGroupId",
		ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlStudentList, DepartmentWindowsDesktop")]
	[ViewModelControlElementDependenceEntity(Title = "Приказы", Order = 1, ParentPropertyName = "StudentGroupId",
		ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlOrderStudentRecordList, DepartmentWindowsDesktop")]
	public class StudentGroupViewModel : ElementViewModel
	{
		[ViewModelControlElementProperty("Направление", ControlType.ControlGuid, MustHaveValue = true, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlEducationDirectionList, DepartmentWindowsDesktop")]
		[MapConfiguration("EducationDirectionId")]
		public Guid EducationDirectionId { get; set; }

		[ViewModelControlListProperty("Шифр", ColumnWidth = 80)]
		[MapConfiguration("EducationDirection.Cipher", IsDifficle = true)]
		public string EducationDirectionCipher { get; set; }

		[ViewModelControlListProperty("Профиль")]
		[MapConfiguration("EducationDirection.Profile", IsDifficle = true)]
		public string EducationDirectionProfile { get; set; }

		[MapConfiguration("EducationDirection.ShortName", IsDifficle = true)]
		public string EducationDirectionShortName { get; set; }

		[ViewModelControlListProperty("Группа")]
		public string GroupName => $"{EducationDirectionShortName}-{(int)AcademicCourse}{GroupNumber}";

		[ViewModelControlElementProperty("Курс", ControlType.ControlEnum, MustHaveValue = true)]
		[MapConfiguration("AcademicCourse")]
		public AcademicCourse AcademicCourse { get; set; }

		[ViewModelControlListProperty("Курс")]
		public string AcademicCourseTitle => AcademicCourse.ToString("G");

		[ViewModelControlListProperty("Номер группы")]
		[ViewModelControlElementProperty("Номер группы", ControlType.ControlInt, MustHaveValue = true, MinValue = 0, MaxValue = 4)]
		[MapConfiguration("GroupNumber")]
		public int GroupNumber { get; set; }

		[ViewModelControlElementProperty("Куратор", ControlType.ControlGuid, MustHaveValue = false, ReadOnly = false, ControlTypeObject = "DepartmentWindowsDesktop.EntityControls.ControlLecturerList, DepartmentWindowsDesktop")]
		[MapConfiguration("LecturerId")]
		public Guid? LecturerId { get; set; }

		[ViewModelControlListProperty("Куратор")]
		[MapConfiguration("Lecturer.ToString", IsDifficle = true)]
		public string Lecturer { get; set; }
	}
}